@@ -26,6 +26,8 @@
 #endif
 
 #include <stdio.h>
+#include <stdint.h>
+#include <inttypes.h>
 #include <curses.h>
 #include <time.h>
 #include <string>
@@ -50,8 +52,8 @@ int iUserNameLen = 8;  // maximum displayed width of a login name
 #define nSizeCols 11   // width given to display size of requests
 
 typedef long tFilePos;             // positions in log file are of this type
-typedef long long int tByteTotal;  // for summing bytes transferred
-typedef unsigned long tIPnum;      // IP aliases only 32 bit at this stage
+typedef uint64_t tByteTotal;       // for summing bytes transferred
+typedef uint32_t tIPnum;           // IP aliases only 32 bit at this stage
 
 const time_t nSecsInDay = 60 * 60 * 24;
 
